#!/usr/bin/perl -w
#
# This file is part of the exilog suite.
#
# http://duncanthrax.net/exilog/
#
# (c) Tom Kistner 2004
#
# See LICENSE for licensing information.
#

package exilog_util;
use POSIX qw( strftime );
use strict;
use exilog_config;

BEGIN {
  use Exporter;
  use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);

  # set the version for version checking
  $VERSION     = 0.1;
  @ISA         = qw(Exporter);
  @EXPORT      = qw(
                      &edt
                      &edv
                      &ina
                      &date_to_stamp
                      &stamp_to_date
                      &human_size
                   );

  %EXPORT_TAGS = ();

  # your exported package globals go here,
  # as well as any optionally exported functions
  @EXPORT_OK   = qw();
}


# checks if scalar is in array
sub ina {
  my $aref = shift || [];
  my $str = shift || "";

  unless (ref($aref) eq 'ARRAY') {
    $aref = [ $aref ];
  };

  foreach (@{ $aref }) {
    return 1 if ($_ eq $str);
  };
  return 0;
};


# exists, defined and true (in perl sense)
sub edt {
  my $h = shift;
  my $hkey = shift;
  return 0 unless (ref($h) eq 'HASH');
  return 1 if ( exists($h->{$hkey}) &&
                defined($h->{$hkey}) &&
                $h->{$hkey} );
  return 0;
};


# exists, defined and valid (that is, not empty)
sub edv {
  my $h = shift;
  my $hkey = shift;
  return 0 unless (ref($h) eq 'HASH');
  return 1 if ( exists($h->{$hkey}) &&
                defined($h->{$hkey}) &&
                $h->{$hkey} ne '' );
  return 0;
};


sub date_to_stamp {
  my $date = shift || "";
  my $tod = shift || "00:00:00";
  my ($year,$month,$mday) = split /\-/, $date;
  my ($hour,$minute,$second) = split /\:/, $tod;
  $year-=1900;
  $month--;
  return strftime("%s",$second,$minute,$hour,$mday,$month,$year);
};


sub stamp_to_date {
  my $stamp = shift;
  # convert to date/time string
  if ($config->{web}->{timestamps} eq 'local') {
    return strftime("%Y-%m-%d %H:%M:%S",localtime($stamp));
  }
  else {
    return strftime("%Y-%m-%d %H:%M:%S",gmtime($stamp));
  };
};

sub human_size {
  my $size = shift;
  my @units = ( '', 'k', 'M', 'G' );
  while ( ($size > 9999) && ((scalar @units) > 1) ) {
    shift @units;
    $size = int($size/1024);
  };
  return $size.$units[0];
};


1;
